''' qtplasmac_custom.py - custom python code for qtplasmac '''

def custom_code(self):
    ''' keep all custom code inside this function '''

    from qtvcp.widgets.led_widget import LED
    from qtvcp.widgets.hal_label import HALLabel

    def pwmgn_clicked(self):
        ''' set cut_amps_pwmgen hal pin and led state'''
        if STATUS.machine_is_on():
            self.h['pwm_led'] = True
            if self.cut_amps_pwmgn.isChecked():
                self.pwmEnablePin.set(True)
                self.pwmgn_led.setFlashing(False)
            else:
                self.pwmEnablePin.set(False)
                self.pwmgn_led.setFlashing(True)

    def b1_clicked(self):
        ''' increment cut_amps-f '''
        self.w.cut_amps.setValue(self.h['cut_amps-f'] + 1)

    def b2_clicked(self):
        ''' decrement cut_amps-f '''
        self.w.cut_amps.setValue(self.h['cut_amps-f'] - 1)

    # get layout to add new frame to
    lay1 = self.w.control_frame.parent().children()[0]
    # remove control_frame from layout
    lay1.removeWidget(self.w.control_frame)
    # create new frame with a layout
    caf = QFrame(objectName='cut_amps_frame')
    lay2 = QVBoxLayout(objectName='cut_amps_layout')
    lay2.setContentsMargins(0, 0, 0, 0) # left, top, right, bottom
    lay2.setSpacing(4) # space between widgets
    caf.setLayout(lay2)
    # label for frame
    cal = QLabel('CUT AMPS', objectName='cut_amps_label')
    cal.setAlignment(Qt.AlignCenter)
    lay2.addWidget(cal)
    g = QGridLayout(objectName='cut_amps_grid')
    g.setContentsMargins(4, 0, 4, 4) # left, top, right, bottom
    lay2.setSpacing(4) # space between widgets
    # pushbutton to enable pwmgn
    self.cut_amps_pwmgn = QPushButton('PWMGN ON/OFF', objectName='cut_amps_pwmgn')
    self.cut_amps_pwmgn.setSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
    self.cut_amps_pwmgn.setCheckable(True)
    self.cut_amps_pwmgn.clicked.connect(lambda:pwmgn_clicked(self))
    # label to display cut_amps-f
    aa = HALLabel()
    aa.setObjectName('cut_amps_2')
    aa.set_float_pin_type(True)
    aa.set_textTemplate('%0.0f')
    aa.setAlignment(Qt.AlignRight)
    aa.set_pin_name('cut_amps_2')
    aa._hal_init()
    # pushbutton to increment/decrement cut_amps-f
    b1 = QPushButton('+', objectName='amps_plus')
    b1.setSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
    b1.clicked.connect(lambda:b1_clicked(self))
    b2 = QPushButton('-', objectName='amps_minus')
    b2.setSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
    b2.clicked.connect(lambda:b2_clicked(self))
    # led to indicate if pwmgen enabled
    self.pwmgn_led = LED()
    self.pwmgn_led.setObjectName('pwm_led')
    self.pwmgn_led.set_pin_name('pwm_led')
    self.pwmgn_led._hal_init()
    # label for led
    l1 = QLabel('ON')
    l1.setAlignment(Qt.AlignCenter)
    # layout the widgets
    g.addWidget(self.cut_amps_pwmgn,0,0,2,2) # row, column, rows, columns
    g.addWidget(b1,0,2,3,1)
    g.addWidget(aa,2,0,4,1)
    g.addWidget(l1,2,1,2,1)
    g.addWidget(b2,3,2,3,1)
    g.addWidget(self.pwmgn_led,4,1,2,1)
    lay2.addLayout(g)
    # add new frame to layout
    lay1.addWidget(caf)
    # add control_frame to layout
    lay1.addWidget(self.w.control_frame)
    # create hal pin and connections
    self.pwmEnablePin = self.h.newpin('cut_amps_pwmgn', hal.HAL_BIT, hal.HAL_OUT)


    # patch handler power_state method so we can run some additional code
    old_power_state = self.power_state
    def new_power_state(state):
        old_power_state(state)
        if state:
            self.cut_amps_pwmgn.setChecked(True)
            self.cut_amps_pwmgn.setEnabled(True)
            self.pwmEnablePin.set(True)
        else:
            self.cut_amps_pwmgn.setChecked(False)
            self.cut_amps_pwmgn.setEnabled(False)
            self.pwmEnablePin.set(False)
        self.h['pwm_led'] = self.cut_amps_pwmgn.isChecked()
    self.power_state = new_power_state

custom_code(self)
